@@ -2,7 +2,9 @@
 import unittest
 
 from ansiblelint.rules import RulesCollection
-from ansiblelint.rules.UsingBareVariablesIsDeprecatedRule import UsingBareVariablesIsDeprecatedRule
+from ansiblelint.rules.UsingBareVariablesIsDeprecatedRule import (
+    UsingBareVariablesIsDeprecatedRule,
+)
 from ansiblelint.runner import Runner
 
 
@@ -13,12 +15,12 @@ class TestUsingBareVariablesIsDeprecated(unittest.TestCase):
         self.collection.register(UsingBareVariablesIsDeprecatedRule())
 
     def test_file_positive(self):
-        success = 'test/using-bare-variables-success.yml'
-        good_runner = Runner(self.collection, success, [], [], [])
+        success = 'examples/playbooks/using-bare-variables-success.yml'
+        good_runner = Runner(success, rules=self.collection)
         self.assertEqual([], good_runner.run())
 
     def test_file_negative(self):
-        failure = 'test/using-bare-variables-failure.yml'
-        bad_runner = Runner(self.collection, failure, [], [], [])
+        failure = 'examples/playbooks/using-bare-variables-failure.yml'
+        bad_runner = Runner(failure, rules=self.collection)
         errs = bad_runner.run()
-        self.assertEqual(14, len(errs))
+        self.assertEqual(11, len(errs))
